@@ -1,5 +1,5 @@
 package Util::Medley::File;
-$Util::Medley::File::VERSION = '0.019';
+$Util::Medley::File::VERSION = '0.020';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -22,7 +22,7 @@ Util::Medley::File - utility file methods
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =cut
 
@@ -393,10 +393,10 @@ convenience wrapper around find.
 
  @files = $util->findFiles($dir);
  
- @files = $util->find( dir => $dir, 
-                      [minDepth => $minDepth],
-                      [maxDepth => $maxDepth],
-                      [extension => $extension] );
+ @files = $util->findFiles( dir => $dir, 
+                           [minDepth => $minDepth],
+                           [maxDepth => $maxDepth],
+                           [extension => $extension] );
 
 =item args:
 
